Delete an edge from a network edges data frame
deleteEdgeFromNetwork.RdRemoves the row(s) from an edges data frame that match the given
source, target, and interaction values. This is
the programmatic counterpart of the interactive Ctrl+click / right-click
edge deletion available in cytoscapeNetwork.
Examples
edges <- data.frame(
source = c("TP53", "MDM2", "CDKN1A"),
target = c("MDM2", "TP53", "TP53"),
interaction = c("Activation", "Inhibition", "Activation"),
stringsAsFactors = FALSE
)
deleteEdgeFromNetwork(edges, "MDM2", "TP53", "Inhibition")
#> source target interaction
#> 1 TP53 MDM2 Activation
#> 3 CDKN1A TP53 Activation